=== modified file 'breezy/plugins/propose/cmds.py'
--- breezy/plugins/propose/cmds.py	2020-01-28 23:34:28 +0000
+++ breezy/plugins/propose/cmds.py	2020-03-07 13:30:38 +0000
@@ -152,6 +152,8 @@
                    help='Labels to apply.'),
         Option('no-allow-lossy',
                help='Allow fallback to lossy push, if necessary.'),
+        Option('allow-collaboration',
+               help='Allow collaboration from target branch maintainer(s)'),
         ]
     takes_args = ['submit_branch?']
 
@@ -159,7 +161,8 @@
 
     def run(self, submit_branch=None, directory='.', hoster=None,
             reviewers=None, name=None, no_allow_lossy=False, description=None,
-            labels=None, prerequisite=None, commit_message=None, wip=False):
+            labels=None, prerequisite=None, commit_message=None, wip=False,
+            allow_collaboration=False):
         tree, branch, relpath = (
             controldir.ControlDir.open_containing_tree_or_branch(directory))
         if submit_branch is None:
@@ -199,7 +202,7 @@
                 description=description, reviewers=reviewers,
                 prerequisite_branch=prerequisite_branch, labels=labels,
                 commit_message=commit_message,
-                work_in_progress=wip)
+                work_in_progress=wip, allow_collaboration=allow_collaboration)
         except _mod_propose.MergeProposalExists as e:
             note(gettext('There is already a branch merge proposal: %s'), e.url)
         else:

=== modified file 'breezy/plugins/propose/github.py'
--- breezy/plugins/propose/github.py	2020-03-07 10:21:23 +0000
+++ breezy/plugins/propose/github.py	2020-03-07 13:30:38 +0000
@@ -280,12 +280,14 @@
             return json.loads(response.text)
         raise InvalidHttpResponse(path, response.text)
 
-    def _create_pull(self, path, title, head, base, body=None, labels=None, assignee=None, draft=False):
+    def _create_pull(self, path, title, head, base, body=None, labels=None,
+                     assignee=None, draft=False, maintainers_can_modify=False):
         data = {
             'title': title,
             'head': head,
             'base': base,
             'draft': draft,
+            'maintainers_can_modify': maintainers_can_modify,
         }
         if labels is not None:
             data['labels'] = labels
@@ -556,7 +558,7 @@
 
     def create_proposal(self, description, reviewers=None, labels=None,
                         prerequisite_branch=None, commit_message=None,
-                        work_in_progress=False):
+                        work_in_progress=False, allow_collaboration=False):
         """Perform the submission."""
         if prerequisite_branch is not None:
             raise PrerequisiteBranchUnsupported(self)
@@ -587,7 +589,9 @@
                 head="%s:%s" % (self.source_owner, self.source_branch_name),
                 base=self.target_branch_name,
                 labels=labels, assignee=assignees,
-                draft=work_in_progress)
+                draft=work_in_progress,
+                maintainer_can_modify=allow_collaboration,
+                )
         except ValidationFailed:
             raise MergeProposalExists(self.source_branch.user_url)
         return GitHubMergeProposal(self.gh, pull_request)

=== modified file 'breezy/plugins/propose/gitlabs.py'
--- breezy/plugins/propose/gitlabs.py	2020-02-18 03:11:01 +0000
+++ breezy/plugins/propose/gitlabs.py	2020-03-07 13:30:38 +0000
@@ -588,7 +588,7 @@
 
     def create_proposal(self, description, reviewers=None, labels=None,
                         prerequisite_branch=None, commit_message=None,
-                        work_in_progress=False):
+                        work_in_progress=False, allow_collaboration=False):
         """Perform the submission."""
         # https://docs.gitlab.com/ee/api/merge_requests.html#create-mr
         if prerequisite_branch is not None:
@@ -600,7 +600,6 @@
         title = determine_title(description)
         if work_in_progress:
             title = 'WIP: %s' % title
-        # TODO(jelmer): Allow setting allow_collaboration field
         # TODO(jelmer): Allow setting milestone field
         # TODO(jelmer): Allow setting squash field
         kwargs = {
@@ -609,7 +608,8 @@
             'target_project_id': target_project['id'],
             'source_branch_name': self.source_branch_name,
             'target_branch_name': self.target_branch_name,
-            'description': description}
+            'description': description,
+            'allow_collaboration': allow_collaboration}
         if labels:
             kwargs['labels'] = ','.join(labels)
         if reviewers:

=== modified file 'breezy/plugins/propose/launchpad.py'
--- breezy/plugins/propose/launchpad.py	2020-02-18 03:11:01 +0000
+++ breezy/plugins/propose/launchpad.py	2020-03-07 13:30:38 +0000
@@ -550,7 +550,7 @@
 
     def create_proposal(self, description, reviewers=None, labels=None,
                         prerequisite_branch=None, commit_message=None,
-                        work_in_progress=False):
+                        work_in_progress=False, allow_collaboration=False):
         """Perform the submission."""
         if labels:
             raise LabelsUnsupported(self)

=== modified file 'breezy/propose.py'
--- breezy/propose.py	2020-02-18 03:11:01 +0000
+++ breezy/propose.py	2020-03-07 13:30:38 +0000
@@ -202,7 +202,7 @@
 
     def create_proposal(self, description, reviewers=None, labels=None,
                         prerequisite_branch=None, commit_message=None,
-                        work_in_progress=False):
+                        work_in_progress=False, allow_collaboration=False):
         """Create a proposal to merge a branch for merging.
 
         :param description: Description for the merge proposal
@@ -212,6 +212,9 @@
         :param commit_message: Optional commit message
         :param work_in_progress:
             Whether this merge proposal is still a work-in-progress
+        :param allow_collaboration:
+            Whether to allow changes to the branch from the target branch
+            maintainer(s)
         :return: A `MergeProposal` object
         """
         raise NotImplementedError(self.create_proposal)

